@@ -160,6 +160,10 @@ pub enum OpKclValue {
     String {
         value: String,
     },
+    SketchVar {
+        value: f64,
+        ty: NumericType,
+    },
     Array {
         value: Vec<OpKclValue>,
     },
@@ -175,6 +179,9 @@ pub enum OpKclValue {
     TagDeclarator {
         name: String,
     },
+    GdtAnnotation {
+        artifact_id: ArtifactId,
+    },
     Plane {
         artifact_id: ArtifactId,
     },
@@ -229,6 +236,10 @@ impl From<&KclValue> for OpKclValue {
             KclValue::Bool { value, .. } => Self::Bool { value: *value },
             KclValue::Number { value, ty, .. } => Self::Number { value: *value, ty: *ty },
             KclValue::String { value, .. } => Self::String { value: value.clone() },
+            KclValue::SketchVar { value, .. } => Self::SketchVar {
+                value: value.initial_value,
+                ty: value.ty,
+            },
             KclValue::Tuple { value, .. } | KclValue::HomArray { value, .. } => {
                 let value = value.iter().map(Self::from).collect();
                 Self::Array { value }
@@ -244,6 +255,9 @@ impl From<&KclValue> for OpKclValue {
             KclValue::TagDeclarator(node) => Self::TagDeclarator {
                 name: node.name.clone(),
             },
+            KclValue::GdtAnnotation { value } => Self::GdtAnnotation {
+                artifact_id: ArtifactId::new(value.id),
+            },
             KclValue::Plane { value } => Self::Plane {
                 artifact_id: value.artifact_id,
             },
