@@ -51,15 +51,34 @@ pub struct Discovered {
 }
 
 impl Discovered {
-    #[cfg(test)]
     pub fn apply_suggestion(&self, src: &str) -> Option<String> {
-        let suggestion = self.suggestion.as_ref()?;
-        Some(format!(
-            "{}{}{}",
-            &src[0..suggestion.source_range.start()],
-            suggestion.insert,
-            &src[suggestion.source_range.end()..]
-        ))
+        self.suggestion.as_ref().map(|suggestion| suggestion.apply(src))
+    }
+}
+
+/// Lint, and try to apply all suggestions.
+/// Returns the new source code, and any lints without suggestions.
+/// # Implementation
+/// Currently, this runs a loop: parse the code, lint it, apply a lint with suggestions,
+/// and loop again, until there's no more lints with suggestions. This is because our auto-fix
+/// system currently replaces the whole program, not just a certain part of it.
+/// If/when we discover that this autofix loop is too slow, we'll change our lint system so that
+/// lints can be applied to a small part of the program.
+pub fn lint_and_fix(mut source: String) -> anyhow::Result<(String, Vec<Discovered>)> {
+    loop {
+        let (program, errors) = crate::Program::parse(&source)?;
+        if !errors.is_empty() {
+            anyhow::bail!("Found errors while parsing, please run the parser and fix them before linting.");
+        }
+        let Some(program) = program else {
+            anyhow::bail!("Could not parse, please run parser and ensure the program is valid before linting");
+        };
+        let lints = program.lint_all()?;
+        if let Some(to_fix) = lints.iter().find_map(|lint| lint.suggestion.clone()) {
+            source = to_fix.apply(&source);
+        } else {
+            return Ok((source, lints));
+        }
     }
 }
 
@@ -205,6 +224,26 @@ pub(crate) use test::{assert_finding, assert_no_finding, test_finding, test_no_f
 #[cfg(test)]
 mod test {
 
+    #[test]
+    fn test_lint_and_fix() {
+        // This file has some snake_case identifiers.
+        let path = "../kcl-python-bindings/files/box_with_linter_errors.kcl";
+        let f = std::fs::read_to_string(path).unwrap();
+        let prog = crate::Program::parse_no_errs(&f).unwrap();
+
+        // That should cause linter errors.
+        let lints = prog.lint_all().unwrap();
+        assert!(lints.len() >= 4);
+
+        // But the linter errors can be fixed.
+        let (new_code, unfixed) = lint_and_fix(f).unwrap();
+        assert!(unfixed.len() < 4);
+
+        // After the fix, no more snake_case identifiers.
+        eprintln!("{new_code}");
+        assert!(!new_code.contains('_'));
+    }
+
     macro_rules! assert_no_finding {
         ( $check:expr_2021, $finding:expr_2021, $kcl:expr_2021 ) => {
             let prog = $crate::Program::parse_no_errs($kcl).unwrap();
@@ -272,4 +311,6 @@ mod test {
     pub(crate) use assert_no_finding;
     pub(crate) use test_finding;
     pub(crate) use test_no_finding;
+
+    use super::*;
 }
