@@ -44,13 +44,13 @@ impl ModuleLoader {
     }
 
     pub(crate) fn enter_module(&mut self, path: &ModulePath) {
-        if let ModulePath::Local { value: path } = path {
+        if let ModulePath::Local { value: path, .. } = path {
             self.import_stack.push(path.clone());
         }
     }
 
     pub(crate) fn leave_module(&mut self, path: &ModulePath) {
-        if let ModulePath::Local { value: path } = path {
+        if let ModulePath::Local { value: path, .. } = path {
             let popped = self.import_stack.pop().unwrap();
             assert_eq!(path, &popped);
         }
@@ -60,6 +60,7 @@ impl ModuleLoader {
 pub(crate) fn read_std(mod_name: &str) -> Option<&'static str> {
     match mod_name {
         "prelude" => Some(include_str!("../std/prelude.kcl")),
+        "gdt" => Some(include_str!("../std/gdt.kcl")),
         "math" => Some(include_str!("../std/math.kcl")),
         "sketch" => Some(include_str!("../std/sketch.kcl")),
         "sketch2" => Some(include_str!("../std/sketch2.kcl")),
@@ -72,6 +73,7 @@ pub(crate) fn read_std(mod_name: &str) -> Option<&'static str> {
         "appearance" => Some(include_str!("../std/appearance.kcl")),
         "transform" => Some(include_str!("../std/transform.kcl")),
         "vector" => Some(include_str!("../std/vector.kcl")),
+        "hole" => Some(include_str!("../std/hole.kcl")),
         _ => None,
     }
 }
@@ -118,21 +120,26 @@ pub enum ModuleRepr {
 pub enum ModulePath {
     // The main file of the project.
     Main,
-    Local { value: TypedPath },
-    Std { value: String },
+    Local {
+        value: TypedPath,
+        original_import_path: Option<TypedPath>,
+    },
+    Std {
+        value: String,
+    },
 }
 
 impl ModulePath {
     pub(crate) fn expect_path(&self) -> &TypedPath {
         match self {
-            ModulePath::Local { value: p } => p,
+            ModulePath::Local { value: p, .. } => p,
             _ => unreachable!(),
         }
     }
 
     pub(crate) async fn source(&self, fs: &FileManager, source_range: SourceRange) -> Result<ModuleSource, KclError> {
         match self {
-            ModulePath::Local { value: p } => Ok(ModuleSource {
+            ModulePath::Local { value: p, .. } => Ok(ModuleSource {
                 source: fs.read_to_string(p, source_range).await?,
                 path: self.clone(),
             }),
@@ -166,7 +173,7 @@ impl ModulePath {
                             path.clone()
                         }
                     }
-                    ModulePath::Local { value } => {
+                    ModulePath::Local { value, .. } => {
                         let import_from_dir = value.parent();
                         let base = import_from_dir.as_ref().or(project_directory.as_ref());
                         if let Some(dir) = base {
@@ -182,7 +189,10 @@ impl ModulePath {
                     }
                 };
 
-                Ok(ModulePath::Local { value: resolved_path })
+                Ok(ModulePath::Local {
+                    value: resolved_path,
+                    original_import_path: Some(path.clone()),
+                })
             }
             ImportPath::Std { path } => Self::from_std_import_path(path),
         }
@@ -210,7 +220,7 @@ impl fmt::Display for ModulePath {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             ModulePath::Main => write!(f, "main"),
-            ModulePath::Local { value: path } => path.fmt(f),
+            ModulePath::Local { value: path, .. } => path.fmt(f),
             ModulePath::Std { value: s } => write!(f, "std::{s}"),
         }
     }
