@@ -1,12 +1,12 @@
 use sha2::{Digest as DigestTrait, Sha256};
 
 use crate::parsing::ast::types::{
-    Annotation, ArrayExpression, ArrayRangeExpression, AscribedExpression, BinaryExpression, BinaryPart, BodyItem,
-    CallExpressionKw, DefaultParamVal, ElseIf, Expr, ExpressionStatement, FunctionExpression, FunctionType, Identifier,
-    IfExpression, ImportItem, ImportSelector, ImportStatement, ItemVisibility, KclNone, LabelledExpression, Literal,
-    LiteralValue, MemberExpression, Name, ObjectExpression, ObjectProperty, Parameter, PipeExpression,
-    PipeSubstitution, PrimitiveType, Program, ReturnStatement, TagDeclarator, Type, TypeDeclaration, UnaryExpression,
-    VariableDeclaration, VariableDeclarator, VariableKind,
+    Annotation, ArrayExpression, ArrayRangeExpression, AscribedExpression, BinaryExpression, BinaryPart, Block,
+    BodyItem, CallExpressionKw, DefaultParamVal, ElseIf, Expr, ExpressionStatement, FunctionExpression, FunctionType,
+    Identifier, IfExpression, ImportItem, ImportSelector, ImportStatement, ItemVisibility, KclNone, LabelledExpression,
+    Literal, LiteralValue, MemberExpression, Name, NumericLiteral, ObjectExpression, ObjectProperty, Parameter,
+    PipeExpression, PipeSubstitution, PrimitiveType, Program, ReturnStatement, SketchBlock, SketchVar, TagDeclarator,
+    Type, TypeDeclaration, UnaryExpression, VariableDeclaration, VariableDeclarator, VariableKind,
 };
 
 /// Position-independent digest of the AST node.
@@ -143,6 +143,8 @@ impl Expr {
             Expr::IfExpression(e) => e.compute_digest(),
             Expr::LabelledExpression(e) => e.compute_digest(),
             Expr::AscribedExpression(e) => e.compute_digest(),
+            Expr::SketchBlock(e) => e.compute_digest(),
+            Expr::SketchVar(e) => e.compute_digest(),
             Expr::None(_) => {
                 let mut hasher = Sha256::new();
                 hasher.update(b"Value::None");
@@ -166,6 +168,7 @@ impl BinaryPart {
             BinaryPart::ObjectExpression(e) => e.compute_digest(),
             BinaryPart::IfExpression(e) => e.compute_digest(),
             BinaryPart::AscribedExpression(e) => e.compute_digest(),
+            BinaryPart::SketchVar(e) => e.compute_digest(),
         }
     }
 }
@@ -214,6 +217,7 @@ impl PrimitiveType {
         let mut hasher = Sha256::new();
         match self {
             PrimitiveType::Any => hasher.update(b"any"),
+            PrimitiveType::None => hasher.update(b"none"),
             PrimitiveType::Named { id } => hasher.update(id.compute_digest()),
             PrimitiveType::String => hasher.update(b"string"),
             PrimitiveType::Number(suffix) => hasher.update(suffix.digestable_id()),
@@ -245,7 +249,7 @@ impl FunctionType {
 impl Parameter {
     compute_digest!(|slf, hasher| {
         hasher.update(slf.identifier.compute_digest());
-        match &mut slf.type_ {
+        match &mut slf.param_type {
             Some(arg) => {
                 hasher.update(b"Parameter::type_::Some");
                 hasher.update(arg.compute_digest())
@@ -347,6 +351,14 @@ impl VariableDeclarator {
     });
 }
 
+impl NumericLiteral {
+    fn digestable_id(&self) -> Vec<u8> {
+        let mut result: Vec<u8> = self.value.to_ne_bytes().into();
+        result.extend((self.suffix as u32).to_ne_bytes());
+        result
+    }
+}
+
 impl Literal {
     compute_digest!(|slf, hasher| {
         hasher.update(slf.value.digestable_id());
@@ -520,6 +532,36 @@ impl ElseIf {
     });
 }
 
+impl SketchBlock {
+    compute_digest!(|slf, hasher| {
+        for argument in &mut slf.arguments {
+            if let Some(l) = &mut argument.label {
+                hasher.update(l.compute_digest());
+            }
+            hasher.update(argument.arg.compute_digest());
+        }
+        hasher.update(slf.body.compute_digest());
+    });
+}
+
+impl Block {
+    compute_digest!(|slf, hasher| {
+        for item in &mut slf.items {
+            hasher.update(item.compute_digest());
+        }
+    });
+}
+
+impl SketchVar {
+    compute_digest!(|slf, hasher| {
+        if let Some(initial) = &slf.initial {
+            hasher.update(initial.digestable_id());
+        } else {
+            hasher.update("no_initial");
+        }
+    });
+}
+
 #[cfg(test)]
 mod test {
     #[tokio::test(flavor = "multi_thread")]
