@@ -144,8 +144,13 @@ async fn inner_extrude(
         let cmd = match (&twist_angle, &twist_angle_step, &twist_center, length.clone(), &to) {
             (Some(angle), angle_step, center, Some(length), None) => {
                 let center = center.clone().map(point_to_mm).map(Point2d::from).unwrap_or_default();
-                let total_rotation_angle = Angle::from_degrees(angle.to_degrees());
-                let angle_step_size = Angle::from_degrees(angle_step.clone().map(|a| a.to_degrees()).unwrap_or(15.0));
+                let total_rotation_angle = Angle::from_degrees(angle.to_degrees(exec_state, args.source_range));
+                let angle_step_size = Angle::from_degrees(
+                    angle_step
+                        .clone()
+                        .map(|a| a.to_degrees(exec_state, args.source_range))
+                        .unwrap_or(15.0),
+                );
                 ModelingCmd::from(mcmd::TwistExtrude {
                     target: sketch.id.into(),
                     distance: LengthUnit(length.to_mm()),
